==> kdepim_4.9.2.orig.tar.xz: kdepim-4.9.2/knotes/resourcenotes.cpp <==
/*******************************************************************
 This file is part of KNotes.

 Copyright (c) 2004, Bo Thorsen <bo@sonofthor.dk>

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 MA  02110-1301, USA.

 In addition, as a special exception, the copyright holders give
 permission to link the code of this program with any edition of
 the Qt library by Trolltech AS, Norway (or with modified versions
 of Qt that use the same license as Qt), and distribute linked
 combinations including the two.  You must obey the GNU General
 Public License in all respects for all of the code used other than
 Qt.  If you modify this file, you may extend this exception to
 your version of the file, but you are not obligated to do so.  If
 you do not wish to do so, delete this exception statement from
 your version.
*******************************************************************/

#include "resourcenotes.h"


ResourceNotes::ResourceNotes()
  : KRES::Resource(), mManager( 0 )
{
  setResourceName( "Notes" );
}

ResourceNotes::ResourceNotes( const KConfigGroup &group )
  : KRES::Resource( group ), mManager( 0 )
{
}

ResourceNotes::~ResourceNotes()
{
}

void ResourceNotes::setManager( KNotesResourceManager *manager )
{
  mManager = manager;
}

KNotesResourceManager * ResourceNotes::manager() const
{
  return mManager;
}

#include "resourcenotes.moc"

==> kdepim-4.11.4.tar.xz: kdepim-4.11.4/knotes/resourcenotes.cpp <==
/*******************************************************************
 This file is part of KNotes.

 Copyright (c) 2004, Bo Thorsen <bo@sonofthor.dk>

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 MA  02110-1301, USA.

 In addition, as a special exception, the copyright holders give
 permission to link the code of this program with any edition of
 the Qt library by Trolltech AS, Norway (or with modified versions
 of Qt that use the same license as Qt), and distribute linked
 combinations including the two.  You must obey the GNU General
 Public License in all respects for all of the code used other than
 Qt.  If you modify this file, you may extend this exception to
 your version of the file, but you are not obligated to do so.  If
 you do not wish to do so, delete this exception statement from
 your version.
*******************************************************************/

#include "resourcenotes.h"


ResourceNotes::ResourceNotes()
  : KRES::Resource(), mManager( 0 )
{
  setResourceName( QLatin1String("Notes") );
}

ResourceNotes::ResourceNotes( const KConfigGroup &group )
  : KRES::Resource( group ), mManager( 0 )
{
}

ResourceNotes::~ResourceNotes()
{
}

void ResourceNotes::setManager( KNotesResourceManager *manager )
{
  mManager = manager;
}

KNotesResourceManager * ResourceNotes::manager() const
{
  return mManager;
}

#include "resourcenotes.moc"
